@@ -10,17 +10,18 @@ class _AttractivenessFinder(object):
         self._session = session or Session.login(settings.AF_USERNAME,
                                                  settings.AF_PASSWORD)
 
-    def find_attractiveness(self, username, accuracy=900,
+    def find_attractiveness(self, username, accuracy=1000,
                             _lower=0, _higher=10000):
         average = (_higher + _lower)//2
         if _higher - _lower <= accuracy:
             return average
 
         results = search(self._session,
-                         looking_for='everybody',
+                         count=1,
+                         gentation='everybody',
                          keywords=username,
                          attractiveness_min=average,
-                         attractiveness_max=_higher)
+                         attractiveness_max=_higher,)
 
         if results:
             return self.find_attractiveness(username, accuracy,
@@ -48,8 +49,9 @@ class CheckForExistenceAttractivenessFinder(AttractivenessFinderDecorator):
 
     def _check_for_existence(self, username):
         return bool(search(self._session,
-                           looking_for='everybody',
-                           keywords=username))
+                           gentation='everybody',
+                           keywords=username,
+                           count=1))
 
 
     def find_attractiveness(self, username, *args, **kwargs):
